Configuration file loading and resolution.
Looks for reclass-config.yml on standard paths, parses the file, and
converts the result into Options that the inventory loader accepts.
Enums
- Error
- Errors that can occur while loading or resolving configuration.
Constants
- CONFIG_
FILE_ NAME - The default configuration file name searched for on disk.
Functions
- configuration_
paths - load
- Load configuration from the first
reclass-config.ymlfound on the search path. - lookup
- Search for a configuration file in standard locations starting from
path.